# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from wordlift_client.models.bot_status import BotStatus
from wordlift_client.models.well_known_files import WellKnownFiles
from typing import Optional, Set
from typing_extensions import Self

class SiteFiles(BaseModel):
    """
    SiteFiles
    """ # noqa: E501
    score: Optional[Annotated[int, Field(le=12, strict=True, ge=0)]] = Field(default=None, description="Numeric score for site files (0-12; up to +2 bonus for WebMCP support)")
    status: Optional[StrictStr] = Field(default=None, description="Overall status of site files")
    explanation: Optional[StrictStr] = Field(default=None, description="Detailed explanation of site files evaluation")
    robots_txt: Optional[StrictStr] = Field(default=None, description="Status of robots.txt file", alias="robotsTxt")
    llms_txt: Optional[StrictStr] = Field(default=None, description="Status of llms.txt file (AI model instructions)", alias="llmsTxt")
    has_llms_txt: Optional[StrictBool] = Field(default=None, description="Whether llms.txt file exists", alias="hasLlmsTxt")
    bot_status: Optional[List[BotStatus]] = Field(default=None, description="Access status for various bots", alias="botStatus")
    well_known: Optional[WellKnownFiles] = Field(default=None, alias="wellKnown")
    __properties: ClassVar[List[str]] = ["score", "status", "explanation", "robotsTxt", "llmsTxt", "hasLlmsTxt", "botStatus", "wellKnown"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Good', 'Needs Improvement', 'Poor', 'Unknown']):
            raise ValueError("must be one of enum values ('Good', 'Needs Improvement', 'Poor', 'Unknown')")
        return value

    @field_validator('robots_txt')
    def robots_txt_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['found', 'not_found', 'error']):
            raise ValueError("must be one of enum values ('found', 'not_found', 'error')")
        return value

    @field_validator('llms_txt')
    def llms_txt_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['found', 'not_found', 'error']):
            raise ValueError("must be one of enum values ('found', 'not_found', 'error')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SiteFiles from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in bot_status (list)
        _items = []
        if self.bot_status:
            for _item in self.bot_status:
                if _item:
                    _items.append(_item.to_dict())
            _dict['botStatus'] = _items
        # override the default output from pydantic by calling `to_dict()` of well_known
        if self.well_known:
            _dict['wellKnown'] = self.well_known.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SiteFiles from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "score": obj.get("score"),
            "status": obj.get("status"),
            "explanation": obj.get("explanation"),
            "robotsTxt": obj.get("robotsTxt"),
            "llmsTxt": obj.get("llmsTxt"),
            "hasLlmsTxt": obj.get("hasLlmsTxt"),
            "botStatus": [BotStatus.from_dict(_item) for _item in obj["botStatus"]] if obj.get("botStatus") is not None else None,
            "wellKnown": WellKnownFiles.from_dict(obj["wellKnown"]) if obj.get("wellKnown") is not None else None
        })
        return _obj


