# coding: utf-8

"""
    WordLift API

    WordLift API

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class WebPage(BaseModel):
    """
    Represents a web page and its extracted content.
    """ # noqa: E501
    abstract: Optional[StrictStr] = Field(default=None, description="A short abstract or excerpt of the web page content.")
    date_published: Optional[date] = Field(default=None, description="The publication date of the web page.")
    headline: Optional[StrictStr] = Field(default=None, description="The headline or title of the web page.")
    html: Optional[StrictStr] = Field(default=None, description="The full HTML content of the web page.")
    image: Optional[StrictStr] = Field(default=None, description="The URL of the primary image of the web page.")
    markdown: Optional[StrictStr] = Field(default=None, description="The extracted content of the web page in Markdown format.")
    status_code: Optional[StrictInt] = Field(default=None, description="The HTTP status code returned when fetching the URL.")
    text: Optional[StrictStr] = Field(default=None, description="The extracted main text content of the web page.")
    types: Optional[List[StrictStr]] = Field(default=None, description="The RDF types for the web page entity.")
    url: Optional[StrictStr] = Field(default=None, description="The canonical URL of the web page.")
    __properties: ClassVar[List[str]] = ["abstract", "date_published", "headline", "html", "image", "markdown", "status_code", "text", "types", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WebPage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WebPage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "abstract": obj.get("abstract"),
            "date_published": obj.get("date_published"),
            "headline": obj.get("headline"),
            "html": obj.get("html"),
            "image": obj.get("image"),
            "markdown": obj.get("markdown"),
            "status_code": obj.get("status_code"),
            "text": obj.get("text"),
            "types": obj.get("types"),
            "url": obj.get("url")
        })
        return _obj


